dnl ###################################################### -*- shell-script -*-
dnl #
dnl #	Copyright (C) 1996-2001  Martin Vicente
dnl #	This file is part of the eXtended C Library (XCLIB).
dnl #
dnl #	This library is free software; you can redistribute it and/or
dnl #	modify it under the terms of the GNU Library General Public
dnl #	License as published by the Free Software Foundation; either
dnl #	version 2 of the License, or (at your option) any later version.
dnl #
dnl #	This library is distributed in the hope that it will be useful,
dnl #	but WITHOUT ANY WARRANTY; without even the implied warranty of
dnl #	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
dnl #	Library General Public License for more details.
dnl #
dnl #	You should have received a copy of the GNU Library General Public
dnl #	License along with this library (see the file COPYING.LIB).
dnl #	If not, write to the Free Software Foundation, Inc.,
dnl #	59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
dnl #
dnl ###########################################################################
dnl #
dnl #	LOCAL ADDITIONS TO AUTOCONF MACROS
dnl #
dnl # Include file for configure.in.
dnl #
dnl #	Project	: "Les outils de Martin"
dnl #	Purpose : Local additions to Autoconf macros
dnl #	File    : aclocal.m4
dnl #	Version : 1.1
dnl #	Language: Autoconf (m4 + Bourne shell)
dnl #	Author	: Martin Vicente
dnl #	Contact	: martin@vicente.org (or martin.vicente@free.fr)
dnl #	Revision: Mon, 14 May 2001
dnl #
dnl ###########################################################################

dnl # MV_STRIP(VAR)
dnl #
define(MV_STRIP, [dnl
# Removes leading and trailing whitespace from VAR and replaces each internal
# sequence of one or more whitespace characters with a single space.
$1=`echo $$1`
])

dnl # MV_PROG_ECHO
dnl #
AC_DEFUN(MV_PROG_ECHO, [dnl
AC_BEFORE([$0], [MV_ECHO_E])dnl
AC_BEFORE([$0], [MV_ECHO_N])dnl
AC_CACHE_CHECK(for echo, mv_cv_prog_ECHO, [dnl
case `uname` in
  OSF1)  ECHO='env CMD_ENV=bsd /bin/echo';;
  SunOS) if test -x /usr/ucb/echo; then
           ECHO=/usr/ucb/echo
         else
           ECHO=echo
         fi;;
  *)     ECHO='echo';;
esac
mv_cv_prog_ECHO=$ECHO])
ECHO=$mv_cv_prog_ECHO
AC_SUBST(ECHO)])

dnl # MV_ECHO_E
dnl #
changequote(`, ')
define(MV_ECHO_E, `dnl
AC_PROVIDE(`$0')dnl
ifdef(`AC_PROVIDE_MV_ECHO_N',
  `errprint(__file__:__line__: `MV_ECHO_N was called before $0
')')
ifdef(`AC_PROVIDE_MV_ESCAPE',
  `errprint(__file__:__line__: `MV_ESCAPE was called before $0
')')
AC_MSG_CHECKING(echo -e)
if ${ECHO-echo} "\033[30mX\033[39m" | >/dev/null grep 33; then
  dnl AC_MSG_RESULT(ECMA-48 SGR sequence not supported)
  if ${ECHO-echo} -e "\033[30mX\033[39m" | >/dev/null grep 33; then
    AC_MSG_RESULT(ECMA-48 SGR sequence not supported with -e)
    mv_escape=no
    mv_e=
  else
    AC_MSG_RESULT(ECMA-48 SGR sequence supported with -e)
    mv_escape=yes
    mv_e=-e
  fi
else
  AC_MSG_RESULT(ECMA-48 SGR sequence supported)
  mv_escape=yes
  mv_e=
fi
')
changequote([, ])

dnl # MV_ECHO_N
dnl #
AC_DEFUN(MV_ECHO_N, [dnl
AC_BEFORE([$0], [MV_ESCAPE])dnl
AC_MSG_CHECKING([echo -n])
if ${ECHO-echo} $mv_e '\c' | >/dev/null grep c; then
  dnl AC_MSG_RESULT(\\c not supported)
  if ${ECHO-echo} $mv_e -n | >/dev/null grep n; then
    AC_MSG_RESULT(option -n not supported)
    mv_nnl=no
    mv_n=
    mv_c=
  else
    AC_MSG_RESULT(option -n supported)
    mv_nnl=yes
    mv_n=-n
    mv_c=
  fi
else
  AC_MSG_RESULT(\\c supported)
  mv_nnl=yes
  mv_n=
  mv_c="\c"
fi
])

dnl # MV_PROG_ECHO_E
dnl #
AC_DEFUN(MV_PROG_ECHO_E, [dnl
AC_REQUIRE([MV_PROG_ECHO])dnl
AC_CACHE_CHECK(for echo -e, mv_cv_prog_ECHO_E, [dnl
ECHO_E="$ECHO $mv_e"
mv_cv_prog_ECHO_E=$ECHO_E])
ECHO_E=$mv_cv_prog_ECHO_E
AC_SUBST(ECHO_E)
color=$mv_escape
AC_SUBST(color)
_E=$mv_e
AC_SUBST(_E)])

dnl # MV_PROG_ECHO_N
dnl #
AC_DEFUN(MV_PROG_ECHO_N, [dnl
AC_REQUIRE([MV_PROG_ECHO_E])dnl
nnl=$mv_nnl
AC_SUBST(nnl)
_N=$mv_n
AC_SUBST(_N)
_C=\"$mv_c\"
AC_SUBST(_C)])

dnl # MV_SET_COLORS
dnl #
define(MV_SET_COLORS, [dnl
###############################################################################
# DISPLAY COLORIZATION
AC_PROVIDE([$0])dnl
ESC=\\033
CSI=\\033${LB}
#
SAVE=${CSI}s
RESTORE=${CSI}u
#
RESET=${ESC}${LB}0m
# video attributes
BOLD=${ESC}${LB}1m
BOLD_OFF=${ESC}${LB}22m
UNDERLINE=${ESC}${LB}4m
UNDERLINE_OFF=${ESC}${LB}24m
BLINK=${ESC}${LB}5m
BLINK_OFF=${ESC}${LB}25m
REVERSE=${ESC}${LB}7m
REVERSE_OFF=${ESC}${LB}27m
# foreground colors
BLACK=${ESC}${LB}30m
RED=${ESC}${LB}31m
GREEN=${ESC}${LB}32m
YELLOW=${ESC}${LB}33m
BLUE=${ESC}${LB}34m
MAGENTA=${ESC}${LB}35m
CYAN=${ESC}${LB}36m
WHITE=${ESC}${LB}37m
DEFAULT=${ESC}${LB}39m
# background colors
BG_BLACK=${ESC}${LB}40m
BG_RED=${ESC}${LB}41m
BG_GREEN=${ESC}${LB}42m
BG_YELLOW=${ESC}${LB}43m
BG_BLUE=${ESC}${LB}44m
BG_MAGENTA=${ESC}${LB}45m
BG_CYAN=${ESC}${LB}46m
BG_WHITE=${ESC}${LB}47m
BG_DEFAULT=${ESC}${LB}49m
])

dnl # MV_ESCAPE(ESCAPE-SEQUENCE)
dnl #
AC_DEFUN(MV_ESCAPE, [dnl
if test $mv_escape = yes; then 1>&AC_FD_MSG ${ECHO-echo} $mv_e $mv_n "$1"$mv_c; fi
])

dnl # MV_BELL_FREQUENCY(HZ)
dnl #
AC_DEFUN(MV_BELL_FREQUENCY, [dnl
MV_ESCAPE(${ESC}${LB}10;$1${RB})])

dnl # MV_BELL_DURATION(MSEC)
dnl #
AC_DEFUN(MV_BELL_DURATION, [dnl
MV_ESCAPE(${ESC}${LB}11;$1${RB})])

dnl # MV_BELL([FREQUENCY], [DURATION], [0])
dnl #
AC_DEFUN(MV_BELL, [dnl
if test -n "$1"; then MV_BELL_FREQUENCY([$1]) fi
if test -n "$2"; then MV_BELL_DURATION([$2])  fi
if test "$3" != 0; then MV_ESCAPE(\a) fi
])

AC_DEFUN(MV_SFX_INIT, [dnl
if test "$silent" != yes; then
  # Audio/Video Effect
  mv_sfx_FREQ=110
  mv_sfx_F1=102
  mv_sfx_F2=100
  mv_sfx_DURA=50000	# micro-seconds
  mv_sfx_D1=100
  mv_sfx_D2=105
  DONE=250000	# micro-seconds
fi
])

AC_DEFUN(MV_SFX_START_A, [dnl
AC_REQUIRE([MV_SFX_INIT])
if test "$silent" != yes; then
  mv_sfx_freq=$mv_sfx_FREQ
  mv_sfx_dura=$mv_sfx_DURA
  MV_ESCAPE($SAVE)
fi
])

AC_DEFUN(MV_SFX_PERFORM_A, [dnl
if test "$silent" != yes; then
  MV_ESCAPE(>)
  if test "$TERM" = linux; then MV_BELL($mv_sfx_freq, 1000) fi
  if test -n "$USLEEP"; then MV_ESCAPE(`$USLEEP $mv_sfx_dura`) fi
  mv_sfx_freq=`expr $mv_sfx_freq \* $mv_sfx_F1 \/ $mv_sfx_F2`
  mv_sfx_dura=`expr $mv_sfx_dura \* $mv_sfx_D1 \/ $mv_sfx_D2`
fi
])

AC_DEFUN(MV_SFX_START_B, [dnl
AC_REQUIRE([MV_SFX_INIT])
if test "$silent" != yes; then
  mv_sfx_freq=$mv_sfx_FREQ
  mv_sfx_dura=$mv_sfx_DURA
  MV_ESCAPE($RESTORE$CYAN)
  mv_sfx_first_time=true
fi
])

AC_DEFUN(MV_SFX_PERFORM_B, [dnl
if test "$silent" != yes; then
  if $mv_sfx_first_time; then :; else MV_ESCAPE(\b$BOLD_OFF>) fi
  MV_ESCAPE($BOLD>)
  if test "$TERM" = linux; then MV_BELL($mv_sfx_freq, 1000) fi
  if test -n "$USLEEP"; then MV_ESCAPE(`$USLEEP $mv_sfx_dura`) fi
  mv_sfx_freq=`expr $mv_sfx_freq \* $mv_sfx_F1 \/ $mv_sfx_F2`
  mv_sfx_dura=`expr $mv_sfx_dura \* $mv_sfx_D1 \/ $mv_sfx_D2`
  mv_sfx_first_time=false
fi
])

AC_DEFUN(MV_SFX_DONE, [dnl
if test "$silent" != yes; then
  if test "$TERM" = linux; then MV_BELL($mv_sfx_freq, 10) fi
  if test -n "$USLEEP"; then MV_ESCAPE(`$USLEEP $DONE`) fi
  if test "$TERM" = linux; then MV_BELL(1000, 250, 0) fi
fi
])

dnl # MV_PROG_TEST
dnl # A utiliser uniquement pour avoir l'option -L (putain de Solaris!)
AC_DEFUN(MV_PROG_TEST, [
case `uname` in
  SunOS) TEST=/bin/test;;
  *)     TEST=test;;
esac
AC_SUBST(TEST)])

dnl # MV_TRANSFORM_MODULES(SRCDIR, LNKDIR, MODULES)
dnl #
define(MV_TRANSFORM_MODULES, [

AC_MSG_CHECKING([and transforming modules name])

mv_SRCDIR="$1"
mv_LNKDIR="$2"
mv_MODULES="$3"

if test ! -d $srcdir; then
  exit 1
fi

if test ! -d $absdir; then
  exit 1
fi

if test ! -d $absdir/$mv_SRCDIR; then
  exit 1
fi

MV_SFX_START_A

for f1 in `echo $mv_MODULES | sed 's/\.o/.c/g'`; do
  f1=$srcdir/$mv_SRCDIR/$f1
  if test ! -f $f1; then
    MV_ESCAPE($RED$BOLD\n)
    AC_MSG_WARN(FILE $f1 IS MISSING)
    MV_ESCAPE($BOLD_OFF$COLOR)
  fi
  MV_SFX_PERFORM_A
done

MV_SFX_DONE

(

if test ! -d $mv_LNKDIR; then mkdir $mv_LNKDIR; fi

cd $mv_LNKDIR

MV_SFX_START_B

for f1 in `echo $mv_MODULES | sed 's/\.o/.c/g'`; do
  f2=`echo $f1 | sed 's/\//__/g'`
  f1=$absdir/$mv_SRCDIR/$f1
  if $TEST ! -L $f2; then
    ln -s $f1 $f2
  fi
  MV_SFX_PERFORM_B
done

MV_SFX_DONE

MV_ESCAPE($BOLD_OFF$COLOR)

)

AC_MSG_RESULT([ done])])

dnl # MV_MSG_RESULT(RESULT-DESCRIPTION)
dnl #
AC_DEFUN(MV_MSG_RESULT, [dnl
MV_ESCAPE($CYAN$BOLD)
AC_MSG_RESULT($1)
MV_ESCAPE($BOLD_OFF$COLOR)])

dnl # MV_SET_LD_SONAME(SONAME)
dnl #
define(MV_SET_LD_SONAME, [dnl
AC_BEFORE([$0], [MV_SET_CC_SHARED_OPTIONS])dnl
mv_GNU_LD_SONAME_OPTION="-soname"
mv_OSF_LD_SONAME_OPTION="-soname"
mv_SUN_LD_SONAME_OPTION="-h"
case `uname` in
  Linux) mv_LD_SONAME_OPTION=$mv_GNU_LD_SONAME_OPTION;;
  OSF1)  mv_LD_SONAME_OPTION=$mv_OSF_LD_SONAME_OPTION;;
  SunOS) mv_LD_SONAME_OPTION=$mv_SUN_LD_SONAME_OPTION;;
  *)     mv_LD_SONAME_OPTION=;;
esac
if test -n "$mv_LD_SONAME_OPTION"; then
  LD_SONAME="$mv_LD_SONAME_OPTION $1"
fi
])

dnl # MV_ADD_LD_RPATH(RPATH)
dnl #
define(MV_ADD_LD_RPATH, [dnl
AC_BEFORE([$0], [MV_SET_CC_LINKER_OPTIONS])dnl
mv_GNU_LD_RPATH_OPTION="-rpath"
mv_OSF_LD_RPATH_OPTION="-rpath"
mv_SUN_LD_RPATH_OPTION="-R"
case `uname` in
  Linux) mv_LD_RPATH_OPTION=$mv_GNU_LD_RPATH_OPTION;;
  OSF1)  mv_LD_RPATH_OPTION=$mv_OSF_LD_RPATH_OPTION;;
  SunOS) mv_LD_RPATH_OPTION=$mv_SUN_LD_RPATH_OPTION;;
  *)     mv_LD_RPATH_OPTION=;;
esac
if test -n "$mv_LD_RPATH_OPTION"; then
  LD_RPATH="$LD_RPATH $mv_LD_RPATH_OPTION $1"
fi
])

dnl # MV_PROG_LD
dnl #
define(MV_PROG_LD, [dnl
###############################################################################
# DETERMINE A LINKER TO USE
AC_PROVIDE([$0])dnl
AC_REQUIRE([AC_PROG_CC])dnl
AC_CACHE_CHECK(for ld, mv_cv_prog_LD, [dnl
if test "$GCC" = yes; then
  LD=`${CC-cc} -print-prog-name=ld`
else
  LD=ld
fi
mv_cv_prog_LD=$LD])
LD=$mv_cv_prog_LD
AC_SUBST(LD)])

dnl # MV_CHECK_LD_GNU
dnl #
AC_DEFUN(MV_CHECK_LD_GNU, [dnl
###############################################################################
# CHECK IF IS GNU LD
AC_REQUIRE([MV_PROG_LD])dnl
AC_CACHE_CHECK(whether we are using the GNU linker, mv_cv_check_gnu_ld, [dnl
if AC_TRY_COMMAND($LD --help) >/dev/null 2>&1; then
  mv_cv_check_gnu_ld=yes
  $1
else
  mv_cv_check_gnu_ld=no
  $2
fi])])

dnl # MV_SET_CC_OVERALL_OPTIONS
dnl #
define(MV_SET_CC_OVERALL_OPTIONS, [dnl
###############################################################################
# SET CC OVERALL OPTIONS
AC_PROVIDE([$0])dnl
AC_REQUIRE([AC_PROG_CC])dnl
AC_MSG_CHECKING(cc: overall  options)
AC_CACHE_VAL(mv_cv_CC_OVERALL_OPTIONS, [dnl
if test "$GCC" = yes; then
  CC_OVERALL_OPTIONS=$GCC_OVERALL_OPTIONS
fi
saved_CC=$CC && CC="$CC $CC_OVERALL_OPTIONS"
AC_TRY_LINK(,,, [CC_OVERALL_OPTIONS=])
CC=$saved_CC
mv_cv_CC_OVERALL_OPTIONS=`echo $CC_OVERALL_OPTIONS`])
CC_OVERALL_OPTIONS=$mv_cv_CC_OVERALL_OPTIONS
CC="$CC $CC_OVERALL_OPTIONS"
MV_MSG_RESULT([$CC_OVERALL_OPTIONS])])

dnl # MV_SET_CC_DIALECT_OPTIONS
dnl #
define(MV_SET_CC_DIALECT_OPTIONS, [dnl
###############################################################################
# SET CC DIALECT OPTIONS
AC_PROVIDE([$0])dnl
AC_REQUIRE([AC_PROG_CC])dnl
AC_MSG_CHECKING(cc: dialect  options)
AC_CACHE_VAL(mv_cv_CC_DIALECT_OPTIONS, [dnl
if test "$GCC" = yes; then
  CC_DIALECT_OPTIONS=$GCC_DIALECT_OPTIONS
fi
saved_CC=$CC && CC="$CC $CC_DIALECT_OPTIONS"
AC_TRY_LINK(,,, [CC_DIALECT_OPTIONS=])
CC=$saved_CC
mv_cv_CC_DIALECT_OPTIONS=`echo $CC_DIALECT_OPTIONS`])
CC_DIALECT_OPTIONS=$mv_cv_CC_DIALECT_OPTIONS
CC="$CC $CC_DIALECT_OPTIONS"
MV_MSG_RESULT([$CC_DIALECT_OPTIONS])])

dnl # MV_SET_CC_WARNING_OPTIONS
dnl #
define(MV_SET_CC_WARNING_OPTIONS, [dnl
###############################################################################
# SET CC WARNING OPTIONS
AC_PROVIDE([$0])dnl
AC_REQUIRE([AC_PROG_CC])dnl
AC_MSG_CHECKING(cc: warning  options)
AC_CACHE_VAL(mv_cv_CC_WARNING_OPTIONS, [dnl
if test "$GCC" = yes; then
  CC_WARNING_OPTIONS=$GCC_WARNING_OPTIONS
fi
mv_cv_CC_WARNING_OPTIONS=`echo $CC_WARNING_OPTIONS`])
CC_WARNING_OPTIONS=$mv_cv_CC_WARNING_OPTIONS
MV_MSG_RESULT([$CC_WARNING_OPTIONS])
AC_SUBST(CC_WARNING_OPTIONS)])

dnl # MV_SET_CC_DEVEL_OPTIONS
dnl #
define(MV_SET_CC_DEVEL_OPTIONS, [dnl
###############################################################################
# SET CC DEVEL OPTIONS
AC_PROVIDE([$0])dnl
AC_REQUIRE([AC_PROG_CC])dnl
AC_MSG_CHECKING(cc: devel    options)
AC_CACHE_VAL(mv_cv_CC_DEVEL_OPTIONS, [dnl
if test "$GCC" = yes; then
  CC_DEVEL_OPTIONS=$GCC_DEVEL_OPTIONS
fi
mv_cv_CC_DEVEL_OPTIONS=`echo $CC_DEVEL_OPTIONS`])
CC_DEVEL_OPTIONS=$mv_cv_CC_DEVEL_OPTIONS
MV_MSG_RESULT([$CC_DEVEL_OPTIONS])
AC_SUBST(CC_DEVEL_OPTIONS)])

dnl # MV_SET_CC_DEBUG_OPTIONS
dnl #
define(MV_SET_CC_DEBUG_OPTIONS, [dnl
###############################################################################
# SET CC DEBUG OPTIONS
AC_PROVIDE([$0])dnl
AC_REQUIRE([AC_PROG_CC])dnl
AC_MSG_CHECKING(cc: debug    options)
AC_CACHE_VAL(mv_cv_CC_DEBUG_OPTIONS, [dnl
if test "$GCC" = yes; then
  CC_DEBUG_OPTIONS=$GCC_DEBUG_OPTIONS
fi
mv_cv_CC_DEBUG_OPTIONS=`echo $CC_DEBUG_OPTIONS`])
CC_DEBUG_OPTIONS=$mv_cv_CC_DEBUG_OPTIONS
MV_MSG_RESULT([$CC_DEBUG_OPTIONS])
AC_SUBST(CC_DEBUG_OPTIONS)])

dnl # MV_SET_CC_OPTIMIZE_OPTIONS
dnl #
define(MV_SET_CC_OPTIMIZE_OPTIONS, [dnl
###############################################################################
# SET CC OPTIMIZE OPTIONS
AC_PROVIDE([$0])dnl
AC_REQUIRE([AC_PROG_CC])dnl
AC_MSG_CHECKING(cc: optimize options)
AC_CACHE_VAL(mv_cv_CC_OPTIMIZE_OPTIONS, [dnl
if test "$GCC" = yes; then
  if test $ARCH = i386; then
    GCC_OPTIMIZE_OPTIONS="$GCC_OPTIMIZE_OPTIONS $GCC_386_OPTIMIZE_OPTIONS"
  fi
  CC_OPTIMIZE_OPTIONS=$GCC_OPTIMIZE_OPTIONS
fi
mv_cv_CC_OPTIMIZE_OPTIONS=`echo $CC_OPTIMIZE_OPTIONS`])
CC_OPTIMIZE_OPTIONS=$mv_cv_CC_OPTIMIZE_OPTIONS
MV_MSG_RESULT([$CC_OPTIMIZE_OPTIONS])
AC_SUBST(CC_OPTIMIZE_OPTIONS)])

dnl # MV_SET_CC_PIC_OPTIONS
dnl #
define(MV_SET_CC_PIC_OPTIONS, [dnl
###############################################################################
# SET CC PIC OPTIONS
AC_PROVIDE([$0])dnl
AC_REQUIRE([AC_PROG_CC])dnl
AC_MSG_CHECKING(cc: PIC      options)
AC_CACHE_VAL(mv_cv_CC_PIC_OPTIONS, [dnl
if test "$GCC" = yes; then
  CC_PIC_OPTIONS=$GCC_PIC_OPTIONS
fi
mv_cv_CC_PIC_OPTIONS=`echo $CC_PIC_OPTIONS`])
CC_PIC_OPTIONS=$mv_cv_CC_PIC_OPTIONS
MV_MSG_RESULT([$CC_PIC_OPTIONS])
AC_SUBST(CC_PIC_OPTIONS)])

dnl # MV_SET_CC_SHARED_OPTIONS
dnl #
define(MV_SET_CC_SHARED_OPTIONS, [dnl
###############################################################################
# SET CC SHARED OPTIONS
AC_PROVIDE([$0])dnl
AC_REQUIRE([AC_PROG_CC])dnl
AC_MSG_CHECKING(cc: shared   options)
AC_CACHE_VAL(mv_cv_CC_SHARED_OPTIONS, [dnl
if test "$GCC" = yes; then
  if test -n "$LD_SONAME"; then
    mv_GCC_SONAME="-Wl"
    for t in $LD_SONAME; do
      mv_GCC_SONAME="$mv_GCC_SONAME,$t"
    done
  fi
  if test -n "$mv_GCC_SONAME"; then
    GCC_SHARED_OPTIONS="$GCC_SHARED_OPTIONS $mv_GCC_SONAME"
  fi
  CC_SHARED_OPTIONS=$GCC_SHARED_OPTIONS
fi
mv_cv_CC_SHARED_OPTIONS=`echo $CC_SHARED_OPTIONS`])
CC_SHARED_OPTIONS=$mv_cv_CC_SHARED_OPTIONS
MV_MSG_RESULT([$CC_SHARED_OPTIONS])
AC_SUBST(CC_SHARED_OPTIONS)])

dnl # MV_SET_CC_LINKER_OPTIONS
dnl #
define(MV_SET_CC_LINKER_OPTIONS, [dnl
###############################################################################
# SET CC LINKER OPTIONS
AC_PROVIDE([$0])dnl
AC_REQUIRE([AC_PROG_CC])dnl
AC_MSG_CHECKING(cc: linker   options)
AC_CACHE_VAL(mv_cv_CC_LINKER_OPTIONS, [dnl
if test "$GCC" = yes; then
  CC_LINKER_OPTIONS=$GCC_LINKER_OPTIONS
fi
mv_cv_CC_LINKER_OPTIONS=`echo $CC_LINKER_OPTIONS`])
CC_LINKER_OPTIONS=$mv_cv_CC_LINKER_OPTIONS
MV_MSG_RESULT([$CC_LINKER_OPTIONS])
AC_SUBST(CC_LINKER_OPTIONS)])

dnl # MV_SET_CC_RPATH_OPTIONS
dnl #
define(MV_SET_CC_RPATH_OPTIONS, [dnl
###############################################################################
# SET CC RPATH OPTIONS
AC_PROVIDE([$0])dnl
AC_REQUIRE([AC_PROG_CC])dnl
AC_MSG_CHECKING(cc: rpath    options)
AC_CACHE_VAL(mv_cv_CC_RPATH_OPTIONS, [dnl
if test "$GCC" = yes; then
  if test -n "$LD_RPATH"; then
    mv_GCC_RPATH="-Wl"
    for t in $LD_RPATH; do
      mv_GCC_RPATH="$mv_GCC_RPATH,$t"
    done
  fi
  if test -n "$mv_GCC_RPATH"; then
    GCC_RPATH_OPTIONS="$GCC_RPATH_OPTIONS $mv_GCC_RPATH"
  fi
  CC_RPATH_OPTIONS=$GCC_RPATH_OPTIONS
fi
mv_cv_CC_RPATH_OPTIONS=`echo $CC_RPATH_OPTIONS`])
CC_RPATH_OPTIONS=$mv_cv_CC_RPATH_OPTIONS
MV_MSG_RESULT([$CC_RPATH_OPTIONS])
AC_SUBST(CC_RPATH_OPTIONS)])

dnl # [END OF FILE]
