/*  Copyright (C) 1996-2001  Martin Vicente			      -*- c -*-
    This file is part of the eXtended C Library (XCLIB).

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library (see the file COPYING.LIB).
    If not, write to the Free Software Foundation, Inc.,
    59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.		     */


/****  Project : eXtended C Library (XCLIB)
    *  Purpose : SYNCHRONOUS I/O MULTIPLEXING
    *  Language: ANSI C
    *  File    : demo_io-1.c
    *  Author  : Martin Vicente <martin@vicente.org>
    *
    ****/


#define _POSIX_SOURCE

#include <unistd.h>

#include <stddef.h>
#include <stdio.h>
#include <assert.h>

#include <xc/error.h>
#include <xc/io.h>

#define UNUSED	__unused

static void echo(IOHandlerId id, int fd, IOEvent op, const void *data);

static void prompt(void);

int main()
{
    prompt();

    io_add_handler(fileno(stdin), ioREAD, echo, NULL);

    puts("Type anything followed by [Return]\n");

    io_main_loop();

    return 0;
}

static void echo(
    UNUSED IOHandlerId id,
    /*  */ int fd,
    /*  */ IOEvent op,
    UNUSED const void *data)
{
    int  ret;
    char chr;

    assert(op == IO_READ);

    ret = read(fd, &chr, sizeof chr);

    if (ret > 0)
    {
	while (ret--)
	{
	    if (chr == '\n')
	    {
		prompt();
	    }
	    else
	    {
		printf("%c%c%c", '[', chr, ']');

		fflush(stdout);
	    }
	}
    }
    else if (ret == 0)
    {
	io_exit_loop();
    }
    else
    {
	error("read failure");
    }
}

static void prompt(void)
{
    printf("-> ");

    fflush(stdout);    
}


/* End of file */
