/*  Copyright (C) 1996-2001  Martin Vicente			      -*- c -*-
    This file is part of the eXtended C Library (XCLIB).

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library (see the file COPYING.LIB).
    If not, write to the Free Software Foundation, Inc.,
    59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.		     */


/*  XCLIB 0.3	LISTD:		SINGLY LINKED LIST WITH DUMMY NODES	     */


#ifndef __XC_ListD_H
#define __XC_ListD_H


/* Standard C Library: */
#include <stddef.h>
#include <assert.h>

/* eXtended C Library: */
#include <xc/version.h>		/* VERSION OF EXTENDED C LIBRARY	     */


/*****************************************************************************
 * CUSTOMIZATION PART
 *****************************************************************************/


#ifndef LD_NodeRec
#define LD_NodeRec  LD_NodeRec
typedef struct node LD_NodeRec;
#endif

#ifndef LD_ListRec
#define LD_ListRec  LD_ListRec
typedef struct list LD_ListRec;
#endif

#ifndef LD_Node
#define LD_Node     LD_Node
typedef LD_NodeRec *LD_Node;
#endif

#ifndef LD_List
#define LD_List     LD_List
typedef LD_ListRec *LD_List;
#endif


#ifndef LD_next
#define LD_next	next
#endif

#ifndef LD_head
#define LD_head	head
#endif

#ifndef LD_tail
#define LD_tail	tail
#endif


/*****************************************************************************
 * INTERNALS
 *****************************************************************************/


#if defined __GNUC__ && !defined __STRICT_ANSI__
#define LD_TYPEREC(NODEREC)	typeof (NODEREC)
#define LD_TYPE(NODE)		typeof (NODE)
#else
#define LD_TYPEREC(NODEREC)	LD_NodeRec
#define LD_TYPE(NODE)		LD_Node
#endif


#define	__LD_NEXT(NODE)	((NODE)->LD_next)
#define	__LD_HEAD(LIST)	((LIST)->LD_head)
#define	__LD_TAIL(LIST)	((LIST)->LD_tail)


#define __LD_FIRST(H, T)	__LD_NEXT(H)


#define __LD_SANITY_CHECK(H, T) assert					      \
									      \
 ( (H) != NULL && (T) != NULL && (					      \
									      \
 __LD_NEXT(H) != NULL &&						      \
 __LD_NEXT(T) == NULL ) )


#define _LD_INIT(H, T)							      \
_MBEGIN									      \
    assert((H) != NULL && (T) != NULL);					      \
									      \
    __LD_NEXT(H) = (T);							      \
    __LD_NEXT(T) = NULL; /* unused */					      \
_MEND

#define _LD_FOREACH_COND(H, T, NODE, COND)				      \
									      \
 for (									      \
									      \
 __LD_SANITY_CHECK(H, T),						      \
									      \
 (NODE) = __LD_FIRST(H, T); (NODE) != (T) && (COND); (NODE) = __LD_NEXT(NODE))

#define _LD_FOREACH(H, T, NODE)	_LD_FOREACH_COND(H, T, NODE, 1)

#define _LD_FOREACH_NODE(H, T, INST)					      \
_MBEGIN									      \
    __XC_REGISTER LD_TYPE(H) __node;					      \
									      \
    _LD_FOREACH(H, T, __node) { INST }					      \
_MEND

#define _LD_NEXT(H, T, N)	(__LD_NEXT(N) != (T) ? __LD_NEXT(N) : NULL)

#define	__LD_PREV(H, T, NODE, PREV)					      \
_MBEGIN									      \
    __XC_REGISTER LD_TYPE(H) ____n;					      \
									      \
    (PREV) = (H);							      \
									      \
    _LD_FOREACH_COND(H, T, ____n, ____n != (NODE)) (PREV) = ____n;	      \
_MEND

#if defined __GNUC__ && !defined __STRICT_ANSI__
#define	_LD_PREV(H, T, NODE)						      \
_MBEGIN									      \
    __XC_REGISTER LD_TYPE(H) ___prev;					      \
									      \
    __LD_PREV(H, T, NODE, ___prev);					      \
									      \
    ___prev != (H) ? ___prev : NULL;					      \
_MEND
#else
#define	_LD_PREV(H, T, NODE, PREV)					      \
_MBEGIN									      \
    __XC_REGISTER LD_TYPE(NODE) ___prev;				      \
									      \
    __LD_PREV(H, T, NODE, ___prev);					      \
									      \
    (PREV) = ___prev != (H) ? ___prev : NULL;				      \
_MEND
#endif

#if defined __GNUC__ && !defined __STRICT_ANSI__
#define	_LD_PPREV(H, T, NODE, PREV)	((PREV) = _LD_PREV(H, T, NODE))
#else
#define	_LD_PPREV(H, T, NODE, PREV)	_LD_PREV(H, T, NODE, PREV)
#endif

#define _LD_FIRST(H, T)							      \
									      \
 (__LD_SANITY_CHECK(H, T), __LD_FIRST(H, T) != (T) ? __LD_FIRST(H, T) : NULL)

#define	__LD_LAST(H, T, LAST)						      \
_MBEGIN									      \
    __XC_REGISTER LD_TYPE(H) ____prev_node = NULL, ____node;		      \
									      \
    _LD_FOREACH(H, T, ____node) ____prev_node = ____node;		      \
									      \
    (LAST) = ____prev_node;						      \
_MEND

#if defined __GNUC__ && !defined __STRICT_ANSI__
#define	_LD_LAST(H, T)							      \
_MBEGIN									      \
    __XC_REGISTER LD_TYPE(H) ____last;					      \
									      \
    __LD_LAST(H, T, ____last);						      \
									      \
    ____last;								      \
_MEND
#else
#define	_LD_LAST(H, T, LAST)						      \
_MBEGIN									      \
    __XC_REGISTER LD_TYPE(H) ____last;					      \
									      \
    __LD_LAST(H, T, ____last);						      \
									      \
    (LAST) = ____last;							      \
_MEND
#endif

#if defined __GNUC__ && !defined __STRICT_ANSI__
#define	_LD_PLAST(H, T, LAST)	((LAST) = _LD_LAST(H, T))
#else
#define	_LD_PLAST(H, T, LAST)	_LD_LAST(H, T, LAST)
#endif

#define _LD_APPEND(H, T, NODE)						      \
_MBEGIN									      \
    __LD_SANITY_CHECK(H, T);						      \
									      \
    _LD_INSERT_BEFORE(H, T, NODE, T);					      \
_MEND

#define _LD_INSERT(H, T, NODE)						      \
_MBEGIN									      \
    __LD_SANITY_CHECK(H, T);						      \
									      \
    _LD_INSERT_AFTER(NODE, H);						      \
_MEND

#define _LD_PREPEND(H, T, NODE) _LD_INSERT(H, T, NODE)

#define _LD_INSERT_BEFORE(H, T, NODE, MARK)				      \
_MBEGIN									      \
    __XC_REGISTER LD_TYPE(H) ___prev_mark;				      \
									      \
    __LD_SANITY_CHECK(H, T);						      \
									      \
    assert((NODE) != NULL);						      \
    assert((MARK) != NULL);						      \
									      \
    __LD_NEXT(NODE) = (MARK);						      \
									      \
    __LD_PREV(H, T, MARK, ___prev_mark);				      \
									      \
    __LD_NEXT(___prev_mark) = (NODE);					      \
_MEND

#define _LD_INSERT_AFTER(NODE, MARK)					      \
_MBEGIN									      \
    assert((NODE) != NULL);						      \
    assert((MARK) != NULL);						      \
									      \
    __LD_NEXT(NODE) = __LD_NEXT(MARK);					      \
									      \
    __LD_NEXT(MARK) = (NODE);						      \
_MEND

#define __LD_REMOVE(H, T, NODE)						      \
_MBEGIN									      \
    __XC_REGISTER LD_TYPE(H) ___prev_node;				      \
									      \
    __LD_SANITY_CHECK(H, T);						      \
									      \
    assert((NODE) != NULL);						      \
									      \
    __LD_PREV(H, T, NODE, ___prev_node);				      \
									      \
    __LD_NEXT(___prev_node) = __LD_NEXT(NODE);				      \
									      \
    __LD_NEXT(NODE) = NULL;						      \
_MEND

#if defined __GNUC__ && !defined __STRICT_ANSI__
#define _LD_REMOVE(H, T, NODE)	(__LD_REMOVE(H, T, NODE), (NODE))
#else
#define _LD_REMOVE(H, T, NODE)	__LD_REMOVE(H, T, NODE)
#endif

#define _LD_EXTRACT(H, T, NODE) _LD_REMOVE(H, T, NODE)

#define _LD_FOREWARD_ACTION(H, T, INST)					      \
_MBEGIN									      \
    __XC_REGISTER LD_TYPE(H) __node, ___next_node;			      \
									      \
    __LD_SANITY_CHECK(H, T);						      \
									      \
    for (__node = __LD_FIRST(H, T); __node != (T); __node = ___next_node)     \
    {									      \
	___next_node = __LD_NEXT(__node);				      \
									      \
	INST								      \
    }									      \
_MEND

#define _LD_BACKWARD_ACTION(H, T, INST)					      \
_MBEGIN									      \
    __XC_REGISTER LD_TYPE(H) __node, ___prev_node;			      \
									      \
    __LD_SANITY_CHECK(H, T);						      \
									      \
    __LD_LAST(H, T, __node);						      \
									      \
    for (; __node != (H); __node = ___prev_node)			      \
    {									      \
	__LD_PREV(H, T, __node, ___prev_node);				      \
									      \
	INST								      \
    }									      \
_MEND

#define _LD_ACTION(H, T, INST)		_LD_FOREWARD_ACTION(H, T, INST)
#define _LD_FWD_ACTION(H, T, INST)	_LD_FOREWARD_ACTION(H, T, INST)
#define _LD_BWD_ACTION(H, T, INST)	_LD_BACKWARD_ACTION(H, T, INST)

#define _LD_CLEAN(H, T, INST)						      \
_MBEGIN									      \
    _LD_ACTION(H, T, INST);						      \
									      \
    _LD_INIT(H, T);							      \
_MEND

#define _LD_PURGE(H, T, INST)	_LD_PURGE(H, T, INST)

#define __LD_LENGTH(H, T, LEN)						      \
_MBEGIN									      \
    __XC_REGISTER size_t __i = 0;					      \
									      \
    _LD_FOREACH_NODE(H, T, __i++;);					      \
									      \
    (LEN) = __i;							      \
_MEND

#if defined __GNUC__ && !defined __STRICT_ANSI__
#define _LD_LENGTH(H, T)						      \
_MBEGIN									      \
    __XC_REGISTER size_t __len;						      \
									      \
    __LD_LENGTH(H, T, __len);						      \
									      \
    __len;								      \
_MEND
#else
#define _LD_LENGTH(H, T, LEN)						      \
_MBEGIN									      \
    __XC_REGISTER size_t __len;						      \
									      \
    __LD_LENGTH(H, T, __len);						      \
									      \
    (LEN) = __len;							      \
_MEND
#endif

#if defined __GNUC__ && !defined __STRICT_ANSI__
#define _LD_PLENGTH(H, T, LEN)	((LEN) = _LD_LENGTH(H, T))
#else
#define _LD_PLENGTH(H, T, LEN)	_LD_LENGTH(H, T, LEN)
#endif

#define __LD_SELECT(H, T, INDEX, NODE)					      \
_MBEGIN									      \
    __XC_REGISTER size_t const __i = (INDEX);				      \
    __XC_REGISTER size_t       __j = 0;					      \
									      \
    _LD_FOREACH(H, T, NODE) if (__j++ == __i) break;			      \
_MEND

#if defined __GNUC__ && !defined __STRICT_ANSI__
#define _LD_SELECT(H, T, INDEX)						      \
_MBEGIN									      \
    __XC_REGISTER LD_TYPE(H) __node;					      \
									      \
    __LD_SELECT(H, T, INDEX, __node);					      \
									      \
    __node;								      \
_MEND
#else
#define _LD_SELECT(H, T, INDEX, NODE)					      \
_MBEGIN									      \
    __XC_REGISTER LD_TYPE(H) __node;					      \
									      \
    __LD_SELECT(H, T, INDEX, __node);					      \
									      \
    (NODE) = __node;							      \
_MEND
#endif

#if defined __GNUC__ && !defined __STRICT_ANSI__
#define _LD_PSELECT(H, T, INDEX, NODE)	((NODE) = _LD_SELECT(H, T, INDEX))
#else
#define _LD_PSELECT(H, T, INDEX, NODE)	_LD_SELECT(H, T, INDEX, NODE)
#endif


/*****************************************************************************
 * HIGH LEVEL MACROS
 *****************************************************************************/


#define _LD_HEAD(LIST)	__LD_HEAD((assert((LIST) != NULL), LIST))
#define _LD_TAIL(LIST)	__LD_TAIL((assert((LIST) != NULL), LIST))


#define LD_INIT(LIST)				_LD_INIT(_LD_HEAD(LIST), _LD_TAIL(LIST))
#define	LD_NEXT(LIST, MARK)			_LD_NEXT(_LD_HEAD(LIST), _LD_TAIL(LIST), MARK)
#define LD_FIRST(LIST)				_LD_FIRST(_LD_HEAD(LIST), _LD_TAIL(LIST))
#define LD_APPEND(LIST, NODE)			_LD_APPEND(_LD_HEAD(LIST), _LD_TAIL(LIST), NODE)
#define LD_INSERT(LIST, NODE)			_LD_INSERT(_LD_HEAD(LIST), _LD_TAIL(LIST), NODE)
#define LD_PREPEND(LIST, NODE)			_LD_PREPEND(_LD_HEAD(LIST), _LD_TAIL(LIST), NODE)
#define LD_INSERT_BEFORE(LIST, NODE, MARK)	_LD_INSERT_BEFORE(_LD_HEAD(LIST), _LD_TAIL(LIST), NODE, MARK)
#define LD_INSERT_AFTER(NODE, MARK)		_LD_INSERT_AFTER(NODE, MARK)
#define LD_REMOVE(LIST, NODE)			_LD_REMOVE(_LD_HEAD(LIST), _LD_TAIL(LIST), NODE)
#define LD_EXTRACT(LIST, NODE)			_LD_EXTRACT(_LD_HEAD(LIST), _LD_TAIL(LIST), NODE)
#define LD_FOREACH_NODE(LIST, INST)		_LD_FOREACH_NODE(_LD_HEAD(LIST), _LD_TAIL(LIST), INST)
#define LD_FOREACH(LIST, NODE)			_LD_FOREACH(_LD_HEAD(LIST), _LD_TAIL(LIST), NODE)
#define LD_FOREACH_COND(LIST, NODE, COND)	_LD_FOREACH_COND(_LD_HEAD(LIST), _LD_TAIL(LIST), NODE, COND)
#define LD_ACTION(LIST, INST)			_LD_ACTION(_LD_HEAD(LIST), _LD_TAIL(LIST), INST)
#define LD_FWD_ACTION(LIST, INST)		_LD_FWD_ACTION(_LD_HEAD(LIST), _LD_TAIL(LIST), INST)
#define LD_BWD_ACTION(LIST, INST)		_LD_BWD_ACTION(_LD_HEAD(LIST), _LD_TAIL(LIST), INST)
#define LD_FOREWARD_ACTION(LIST, INST)		_LD_FOREWARD_ACTION(_LD_HEAD(LIST), _LD_TAIL(LIST), INST)
#define LD_BACKWARD_ACTION(LIST, INST)		_LD_BACKWARD_ACTION(_LD_HEAD(LIST), _LD_TAIL(LIST), INST)
#define LD_CLEAN(LIST, INST)			_LD_CLEAN(_LD_HEAD(LIST), _LD_TAIL(LIST), INST)
#define LD_PURGE(LIST, INST)			_LD_PURGE(_LD_HEAD(LIST), _LD_TAIL(LIST), INST)

/*
 * Non portable versions
 */

#if defined __GNUC__ && !defined __STRICT_ANSI__

/* ====> Function behaviour */

#define LD_PREV(LIST, MARK)			_LD_PREV((_LD_HEAD(LIST), _LD_TAIL(LIST), MARK)
#define LD_LAST(LIST)				_LD_LAST(_LD_HEAD(LIST), _LD_TAIL(LIST))
#define LD_LENGTH(LIST)				_LD_LENGTH(_LD_HEAD(LIST), _LD_TAIL(LIST))
#define LD_SELECT(LIST, I)			_LD_SELECT(_LD_HEAD(LIST), _LD_TAIL(LIST), I)

#else

/* ====> strict ANSI conformance */

#define LD_PREV(LIST, MARK, PREV)		_LD_PREV(_LD_HEAD(LIST), _LD_TAIL(LIST), MARK, PREV)
#define LD_LAST(LIST, LAST)			_LD_LAST(_LD_HEAD(LIST), _LD_TAIL(LIST), LAST)
#define LD_LENGTH(LIST, LEN)			_LD_LENGTH(_LD_HEAD(LIST), _LD_TAIL(LIST), LEN)
#define LD_SELECT(LIST, I, NODE)		_LD_SELECT(_LD_HEAD(LIST), _LD_TAIL(LIST), I, NODE)

#endif

/*
 * Portable versions
 */

#define LD_PPREV(LIST, MARK, PREV)		_LD_PPREV(_LD_HEAD(LIST), _LD_TAIL(LIST), MARK, PREV)
#define LD_PLAST(LIST, LAST)			_LD_PLAST(_LD_HEAD(LIST), _LD_TAIL(LIST), LAST)
#define LD_PLENGTH(LIST, LEN)			_LD_PLENGTH(_LD_HEAD(LIST), _LD_TAIL(LIST), LEN)
#define LD_PSELECT(LIST, I, NODE)		_LD_PSELECT(_LD_HEAD(LIST), _LD_TAIL(LIST), I, NODE)


#endif /* XC ListD HEADER */


/*------------------------------/ END OF FILE /------------------------------*/
