/*  Copyright (C) 1996-2001  Martin Vicente			      -*- c -*-
    This file is part of the eXtended C Library (XCLIB).

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library (see the file COPYING.LIB).
    If not, write to the Free Software Foundation, Inc.,
    59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.		     */


/*  XCLIB 0.3	INTS:		INTEGER TYPES				     */


#ifndef __XC_INTS_H
#define __XC_INTS_H


/* Standard C Library: */
#ifdef HAVE_STDINT_H
#include <stdint.h> /*  EXPERIMENTAL (if you have any problem, mail me) */
#endif

/* eXtended C Library: */
#include <xc/version.h>		/* VERSION OF EXTENDED C LIBRARY	     */


#ifdef __LONG64__
#  define __INT64_C(c)	c ## L
#  define __UINT64_C(c)	c ## UL
#else
#  define __INT64_C(c)	c ## LL
#  define __UINT64_C(c)	c ## ULL
#endif


#ifndef INT8_MAX
#define INT8_MAX	127
#endif
#ifndef INT16_MAX
#define INT16_MAX	32767
#endif
#ifndef INT32_MAX
#define INT32_MAX	2147483647
#endif
#ifndef INT64_MAX
#define INT64_MAX	__INT64_C(9223372036854775807)
#endif

#ifndef INT8_MIN
#define INT8_MIN	(- INT8_MAX - 1)
#endif
#ifndef INT16_MIN
#define INT16_MIN	(- INT16_MAX - 1)
#endif
#ifndef INT32_MIN
#define INT32_MIN	(- INT32_MAX - 1)
#endif
#ifndef INT64_MIN
#define INT64_MIN	(- INT64_MAX - 1)
#endif

#ifndef UINT8_MAX
#define UINT8_MAX	(2U * INT8_MAX + 1)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX	(2U * INT16_MAX + 1)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX	(2U * INT32_MAX + 1)
#endif
#ifndef UINT64_MAX
#define UINT64_MAX	(__UINT64_C(2) * INT64_MAX + 1)
#endif


typedef   signed           char  int8;
typedef unsigned           char uint8;
typedef   signed short     int   int16;
typedef unsigned short     int  uint16;
#ifdef __LONG64__
typedef	  signed           int   int32;
typedef	unsigned           int  uint32;
typedef   signed long      int   int64;
typedef unsigned long      int  uint64;
#else
typedef   signed long      int   int32;
typedef unsigned long      int  uint32;
#ifdef __GNUC__
TYPEDEF   signed long long int   int64;
TYPEDEF unsigned long long int  uint64;
#endif
#endif

#define  int8	 int8
#define uint8	uint8
#define  int16	 int16
#define uint16	uint16
#ifdef __LONG64__
#define  int32	 int32
#define uint32	uint32
#define  int64	 int64
#define uint64	uint64
#else
#define  int32	 int32
#define uint32	uint32
#ifdef __GNUC__
#ifdef __STRICT_ANSI__
#define  int64	 int64
#define uint64	uint64
#else
#define  int64	 int64
#define uint64	uint64
#endif
#endif
#endif


typedef uint8	bits8;
typedef uint16	bits16;
typedef uint32	bits32;
#ifdef  uint64
typedef uint64	bits64;
#endif

#define bits8	bits8
#define bits16	bits16
#define bits32	bits32
#ifdef  uint64
#define bits64	bits64
#endif


extern char  __xcint(force_ints);
#ifdef __PARANOID__
static char *__xclib(local_ints) __unused = &__xcint(force_ints);
#endif


#endif /* XC INTS HEADER */


/*------------------------------/ END OF FILE /------------------------------*/
