/*  Copyright (C) 1996-2001  Martin Vicente			      -*- c -*-
    This file is part of the eXtended C Library (XCLIB).

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library (see the file COPYING.LIB).
    If not, write to the Free Software Foundation, Inc.,
    59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.		     */


/*  XCLIB 0.3	MACROS:		SOME USEFUL MACROS			     */


#ifndef __XC_MACROS_H
#define __XC_MACROS_H


/* Standard C Library: */
#include <stddef.h>

/* eXtended C Library: */
#include <xc/version.h>		/* VERSION OF EXTENDED C LIBRARY	     */


#define ever	(;;)

#define cardinal(array)	(sizeof array / sizeof array[0])


#define	XOR(a, b)	(((a) && !(b)) || (!(a) && (b)))


#define BOOL(x)		((x) ? 1 : 0)
#define ISEVEN(x)	(((x) & 1) == 0)	/* even (pair)   */
#define ISODD(x)	(((x) & 1) == 1)	/* odd  (impair) */
#define	SIGN(x)		((x) < 0 ? -1 : (x) > 0 ? +1 : 0)
#define	ABS(x)		((x) < 0 ? -(x) : (x))
#define SQR(x)		((x) * (x))
#define CUBE(x)		((x) * (x) * (x))


#define CLAMP(x, min, max) ((x) < (min) ? (min) : (x) > (max) ? (max) : (x))
#define LERP(x, min, max)  ((min) + ((max) - (min)) * (x))
#define OOR(x, min, max)   ((x) < (min) || (x) > (max))


#define	__XC_ROUND(T, x) ((x) < 0 ? (x) - __XC_T_1_2(T) : (x) + __XC_T_1_2(T))

#ifdef __GNUC__
#define _XC_ROUND(x)	__XC_ROUND(__typeof (x), x)
#else
#define _XC_ROUND(x)	__XC_ROUND(double, x)
#endif

#define ROUND(x)	((     int)_XC_ROUND(x))
#define ROUNDL(x)	((long int)_XC_ROUND(x))


#undef	MIN
#undef	MAX

#define MIN(x, y)	((x) < (y) ? (x) : (y))
#define	MAX(x, y)	((x) > (y) ? (x) : (y))


#define XCH(type, a, b)							\
_MBEGIN									\
    __XC_REGISTER const type __tmp = (a); (a) = (b); (b) = __tmp;	\
_MEND


#if defined __GNUC__ && !defined __STRICT_ANSI__

#if defined _XCLIB_SOURCE || defined _XC_MACROS_SOURCE

#undef	min
#undef	max

#define xor(a, b)		Mxor(a, b)
#define bool(x)			Mbool(x)
#define iseven(x)		Miseven(x)
#define isodd(x)		Misodd(x)
#define sign(x)			Msign(x)
#define abs(x)			Mabs(x)
#define sqr(x)			Msqr(x)
#define cube(x)			Mcube(x)
#define clamp(x, min, max)	Mclamp(x, min, max)
#define lerp(x, min, max)	Mlerp(x, min, max)
#define oor(x, min, max)	Moor(x, min, max)
#define round(x)		Mround(x)
#define roundl(x)		Mroundl(x)
#define min(x, y)		Mmin(x, y)
#define max(x, y)		Mmax(x, y)
#define swap(a, b)		Mswap(a, b)

#endif

#define Mxor(a, b)		__XC_GNUC_OP2(XOR, a, b)
#define Mbool(x)		__XC_GNUC_OP(BOOL, x)
#define Miseven(x)		__XC_GNUC_OP(ISEVEN, x)
#define Misodd(x)		__XC_GNUC_OP(ISODD, x)
#define Msign(x)		__XC_GNUC_OP(SIGN, x)
#define Mabs(x)			__XC_GNUC_OP(ABS, x)
#define Msqr(x)			__XC_GNUC_OP(SQR, x)
#define Mcube(x)		__XC_GNUC_OP(CUBE, x)
#define Mclamp(x, min, max)	__XC_GNUC_OP3(CLAMP, x, min, max)
#define Mlerp(x, min, max)	__XC_GNUC_OP3(LERP, x, min, max)
#define Moor(x, min, max)	__XC_GNUC_OP3(OOR, x, min, max)
#define Mround(x)		__XC_GNUC_OP(ROUND, x)
#define Mroundl(x)		__XC_GNUC_OP(ROUNDL, x)
#define Mmin(x, y)		__XC_GNUC_OP2(MIN, x, y)
#define Mmax(x, y)		__XC_GNUC_OP2(MAX, x, y)
#define Mswap(a, b)		XCH(typeof(a), a, b)

#define __XC_GNUC_OP(OP, x)					\
_MBEGIN								\
    __XC_REGISTER const typeof(x) __ ## OP ## _x = (x);		\
    __XC_REGISTER const typeof(OP(x)) __ ## OP ## _r =		\
								\
	OP(__ ## OP ## _x);					\
								\
    __ ## OP ## _r;						\
_MEND

#define __XC_GNUC_OP2(OP, x, y)					\
_MBEGIN								\
    __XC_REGISTER const typeof(x) __ ## OP ## _x = (x);		\
    __XC_REGISTER const typeof(y) __ ## OP ## _y = (y);		\
    __XC_REGISTER const typeof(OP(x, y)) __ ## OP ## _r =	\
								\
	OP(__ ## OP ## _x, __ ## OP ## _y);			\
								\
    __ ## OP ## _r;						\
_MEND

#define __XC_GNUC_OP3(OP, x, y, z)				\
_MBEGIN								\
    __XC_REGISTER const typeof(x) __ ## OP ## _x = (x);		\
    __XC_REGISTER const typeof(y) __ ## OP ## _y = (y);		\
    __XC_REGISTER const typeof(z) __ ## OP ## _z = (z);		\
    __XC_REGISTER const typeof(OP(x, y, z)) __ ## OP ## _r =	\
								\
	OP(__ ## OP ## _x, __ ## OP ## _y, __ ## OP ## _z);	\
								\
    __ ## OP ## _r;						\
_MEND

#endif


#ifndef DEG2RAD
#define DEG2RAD	(_XC_PI/180.)
#endif
    
#ifndef RAD2DEG
#define RAD2DEG	(180./_XC_PI)
#endif

#define deg2rad(angle)	(DEG2RAD * (angle))
#define rad2deg(angle)	(RAD2DEG * (angle))


#endif /* XC MACROS HEADER */


/*------------------------------/ END OF FILE /------------------------------*/
