/*  Copyright (C) 1996-2001  Martin Vicente			      -*- c -*-
    This file is part of the eXtended C Library (XCLIB).

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library (see the file COPYING.LIB).
    If not, write to the Free Software Foundation, Inc.,
    59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.		     */


/*  XCLIB 0.3	OPTIONS:	PARSE COMMAND LINE OPTIONS		     */


/*  !!! WARNING !!!    E X P E R I M E N T A L    !!! WARNING !!!  */


#ifndef __XC_OPTIONS_H
#define __XC_OPTIONS_H


#ifndef __EXPERIMENTAL__
#warning "<xc/options.h> is experimental"
#endif


/* Standard C Library: */
#include <stddef.h>

/* eXtended C Library: */
#include <xc/bool.h>		/* BOOLEAN TYPE				     */
#include <xc/cdecl.h>		/* C DECLARATIONS			     */


enum OptionKind
{
    OptionKindNoArg,
    OptionKindSepArg
};

enum OptionType
{
    OptionTypeChar,
    OptionTypeBool,
    OptionTypeInt,
    OptionTypeFloat,
    OptionTypeDouble,
    OptionTypeString,
    OptionTypePointer
};

union OptionValue
{
    char        _char;
    bool        _bool;
    int         _int;
    float       _float;
    double      _double;
    const char *_string;
    void       *_pointer;
};

typedef enum  OptionKind  OptionKind;
typedef enum  OptionType  OptionType;
typedef union OptionValue OptionValue;

struct Option
{
    size_t      offset;
    const char *name;
    OptionKind  kind;
    OptionType  type;
    OptionValue reset_value;
    OptionValue setup_value;
};

typedef struct Option Option;


#define OPTION(DATA, FIELD, NAME, KIND, TYPE, RESET, SETUP)	\
	{							\
		offsetof(DATA, FIELD), NAME,			\
		OptionKind ## KIND, OptionType ## TYPE,		\
		(OptionValue)RESET, (OptionValue)SETUP		\
	}


#define parse_options(base, options, noptions, argc, argv)	\
 __xclib(parse_options)(base, options, noptions, argc, argv)


_CDECL void __xclib(parse_options)(
    void         *base,
    const Option *options,
    size_t        noptions,
    int          *argc,
    char        **argv);


#endif /* XC OPTIONS HEADER */


/*------------------------------/ END OF FILE /------------------------------*/
