/*  XCLIB - a set of C functions for general purposes		      -*- c -*-
    Copyright (C) 1996-2001  Martin Vicente

    This file is part of the eXtended C Library (XCLIB).

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library (see the file COPYING.LIB).
    If not, write to the Free Software Foundation, Inc.,
    59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.		     */


/*|+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++|*\
  |  Martin Vicente, 1996-2001
  |
  | Project : XCLIB (eXtended C Library)
  | Purpose : GEOMETRIC COMPUTATION
  | Version : 0.3
  | Language: ANSI C
  | File    : geom/isinside.h
  | Author  : Martin VICENTE <martin@vicente.org>
\*|+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++|*/


/*****************************************************************************\

\*****************************************************************************/


#define CARD	unsigned int

#if !defined INTEGER && !defined FLOATING_POINT ||\
     defined INTEGER &&  defined FLOATING_POINT
#error "xclib: *** INTEGER or FLOATING_POINT!"
#endif

#define y1 ____y1

bool FNAME(TYPE x, TYPE y, const TYPE xpoly[], const TYPE ypoly[], CARD n)
{
    TYPE angle, a1;

    register size_t i;

    assert(xpoly != NULL && ypoly != NULL && n > 0);

    angle = 0;

    {
	TYPE const x1 = xpoly[n - 1] - x;
	TYPE const y1 = ypoly[n - 1] - y;

	if (x1 == 0 && y1 == 0) return true;

	a1 = ATAN2(y1, x1);
    }

    for (i = 0; i < n; ++i)
    {
	TYPE a2, da;

	{
	    TYPE const x2 = xpoly[i] - x;
	    TYPE const y2 = ypoly[i] - y;

	    if (x2 == 0 && y2 == 0) return true;

	    a2 = ATAN2(y2, x2);
	}

	da = a2 - a1; /* est la variation d'angle correspondant  ce ct. */ 

	a1 = a2;

	/* Recadrage eventuel de la valeur avant de ... */
	while (da < -PI) da += 2 * PI;
	while (da > +PI) da -= 2 * PI;

	/* ... la sommer. */
	angle += da;
    }

    return Abs(angle) > PI; /* En fait, 2 cas: 0 ou 2.PI radians. */
}


/* END OF FILE */
