/*  XCLIB - a set of C functions for general purposes		      -*- c -*-
    Copyright (C) 1996-2001  Martin Vicente

    This file is part of the eXtended C Library (XCLIB).

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library (see the file COPYING.LIB).
    If not, write to the Free Software Foundation, Inc.,
    59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.		     */


/*|+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++|*\
  |  Martin Vicente, 1996-2001
  |
  | Project : XCLIB (eXtended C Library)
  | Purpose : INTEGER TYPES
  | Version : 0.3
  | Language: ANSI C
  | File    : ints/ints.c
  | Author  : Martin VICENTE <martin@vicente.org>
\*|+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++|*/


#define _XCLIB_INTERNALS

#define _FACILITY	FACILITY(ints)

#undef NDEBUG	/* REQUIRED */

#include <stddef.h>
#include <limits.h>
#include <stdlib.h>
#include <stdio.h>
#include <assert.h>

#include "xc/ints.h"

#include "global.h"

GLOBAL char __xcint(force_ints) = 0;

#define TEST(Tbase, Tnbits) assert(sizeof (Tbase##Tnbits) * CHAR_BIT == Tnbits)

#include "startup.h"
{
    assert(sizeof  (char)  == 1);
    assert(CHAR_BIT        >= 8);

    assert(sizeof  (int8)  == 1);
    assert(sizeof (uint8)  == 1);
    assert(sizeof (bits8)  == 1);

    assert(sizeof  (int16) == 2);
    assert(sizeof (uint16) == 2);
    assert(sizeof (bits16) == 2);

    assert(sizeof  (int32) == 4);
    assert(sizeof (uint32) == 4);
    assert(sizeof (bits32) == 4);

#if defined __LONG64__ || defined __GNUC__
    assert(sizeof  (int64) == 8);
    assert(sizeof (uint64) == 8);
    assert(sizeof (bits64) == 8);
#endif

    TEST( int,  8);
    TEST(uint,  8);
    TEST( int, 16);
    TEST(uint, 16);
    TEST( int, 32);
    TEST(uint, 32);

    if (getenv("VERBOSE") != NULL) puts("<" _FACILITY ">\t-> OK");
}


/* End Of File */
